aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAurelian R <arusanu@gmail.com>2026-03-30 21:39:09 +0300
committerAurelian R <arusanu@gmail.com>2026-03-30 21:39:09 +0300
commitf66fcbcba5fd0aa38e9e610a3202c6dd4232b9eb (patch)
tree90817f76efb7bba778aeb28661ab3459e3ce1cea
parent02713c310291c64bf080307983de799444c792ea (diff)
downloadmsec-f66fcbcba5fd0aa38e9e610a3202c6dd4232b9eb.tar
msec-f66fcbcba5fd0aa38e9e610a3202c6dd4232b9eb.tar.gz
msec-f66fcbcba5fd0aa38e9e610a3202c6dd4232b9eb.tar.bz2
msec-f66fcbcba5fd0aa38e9e610a3202c6dd4232b9eb.tar.xz
msec-f66fcbcba5fd0aa38e9e610a3202c6dd4232b9eb.zip
Fix an error in acl pattern and limit the icon sizes
-rwxr-xr-xsrc/msec/config.py4
-rwxr-xr-xsrc/msec/msecgui.py3
2 files changed, 4 insertions, 3 deletions
diff --git a/src/msec/msecgui.py b/src/msec/msecgui.py
index 05d11a5..cc20452 100755
--- a/src/msec/msecgui.py
+++ b/src/msec/msecgui.py
@@ -604,7 +604,8 @@ class MsecGui(Gtk.Window):
try:
# logo
image = Gtk.Image()
- pixbuf = GdkPixbuf.Pixbuf.new_from_file(icon)
+ # use a fixed size for icons to avoid oveload
+ pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(icon, 32, 32)
image.set_from_pixbuf(pixbuf)
image.set_hexpand(False)
grid.attach(image, 0, row, 1, 1)
diff --git a/src/msec/config.py b/src/msec/config.py
index e77e9fd..0da2389 100755
--- a/src/msec/config.py
+++ b/src/msec/config.py
@@ -433,8 +433,8 @@ class PermConfig(MsecConfig):
except:
self.log.error(_("Unable to load configuration file %s: %s") % (self.config, sys.exc_info()[1]))
return False
- # Look up for pattern: user1:acl,user2:acl
- acl_re = re.compile(r'^([A-Za-z][A-Za-z0-9._-]+:[^:,]+)(,([A-Za-z][A-Za-z0-9._-]*)+:[^:,]+)*$')
+ # Look up acl pattern: user1:rwx,user2:x
+ acl_re = re.compile(r'^[a-z][a-z0-9_-]+:(?:[rwx]{1,3})(?:,[a-z][a-z0-9_-]+:[rwx]{1,3})*$')
for line in fd.readlines():
line = line.strip()
if not line: